Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/cluster/hipClusterCompilerDirective.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

124 lines
3.8 KiB
C++

/*
Copyright (c) 2025 Advanced Micro Devices, Inc. All rights reserved.
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#include <hip_test_common.hh>
#include <hip_test_checkers.hh>
#include <hip/hip_ext.h>
#include "ClusterHelper.hpp"
/**
* @addtogroup cluster
* @{
* @ingroup ClusterTest
* Contains unit tests for cluster launch using compiler directives and launch
*/
#define CLX 2
#define CLY 1
#define CLZ 1
__global__ void CLUSTER_DIMS(CLX, CLY, CLZ) ClusterLaunchKernelBasicCD(int* in, int* out, int n) {
int idx = blockDim.x * blockIdx.x + threadIdx.x;
if (idx < n) {
out[idx] = in[idx];
}
}
/**
* Test Description
* ------------------------
* - Launches kernel with compiler directives that takes cluster dimensions to launch across
* different compute units.
*
* Test source
* ------------------------
* - catch/unit/cluster/hipClusterCompilerDirective.cc
*
* Test requirements
* ------------------------
* - HIP_VERSION >= 7.0
*/
constexpr size_t num_elems = 64;
constexpr size_t num_size = num_elems * sizeof(int);
constexpr int nbig = 16; // number of blocks in grid.
constexpr int ntib = 512; // number of threads in blocks.
void SetupHostMemory(int*& hptr_in, int*& hptr_out) {
hptr_in = (int*)malloc(num_size);
hptr_out = (int*)malloc(num_size);
memset(hptr_in, 0x00, num_size);
memset(hptr_out, 0x00, num_size);
for (size_t idx = 0; idx < num_elems; ++idx) {
hptr_in[idx] = static_cast<int>(idx);
}
}
void SetupDeviceMemory(int*& dptr_in, int*& dptr_out) {
HIP_CHECK(hipMalloc(&dptr_in, num_size));
HIP_CHECK(hipMalloc(&dptr_out, num_size));
HIP_CHECK(hipMemset(dptr_in, 0x00, num_size));
HIP_CHECK(hipMemset(dptr_out, 0x00, num_size));
}
void ReleaseHostAndDeviceMemory(int* hptr_in, int* hptr_out, int* dptr_in, int* dptr_out) {
HIP_CHECK(hipFree(dptr_in));
HIP_CHECK(hipFree(dptr_out));
free(hptr_in);
free(hptr_out);
}
HIP_TEST_CASE(Unit_hipClusterLaunch_CompilerDirective_Basic) {
if (!CheckTargetSupport()) {
INFO("Target Not Supported!");
return;
}
BasicMemoryAllocator<int> bma(num_elems);
int* hptr_in = bma.CreateAndResetHostMemory();
int* hptr_out = bma.CreateAndResetHostMemory();
int* dptr_in = bma.CreateAndResetDeviceMemory();
int* dptr_out = bma.CreateAndResetDeviceMemory();
assert(hptr_in != nullptr && hptr_out != nullptr && dptr_in != nullptr && dptr_out != nullptr);
HIP_CHECK(hipMemcpy(dptr_in, hptr_in, num_size, hipMemcpyHostToDevice));
ClusterLaunchKernelBasicCD<<<nbig, ntib>>>(dptr_in, dptr_out, num_elems);
HIP_CHECK(hipDeviceSynchronize());
HIP_CHECK(hipMemcpy(hptr_out, dptr_out, num_size, hipMemcpyDeviceToHost));
REQUIRE(bma.ValidateArrays(hptr_in, hptr_out));
bma.DestroyHostMemory(hptr_in);
bma.DestroyHostMemory(hptr_out);
bma.DestroyDeviceMemory(dptr_in);
bma.DestroyDeviceMemory(dptr_out);
}
/**
* End doxygen group ClusterTest.
* @}
*/